Attribute VB_Name = "GPIB32"
'*********************************************************************
'
'      GPIB Library
'
'  File: GPIB-32.BAS
'
'
' This file contains the Visual BASIC (32 bit) declarations for all
' GPIB library commands.   This file should be imported via Visual
' BASIC's Load Text command (from the code menu).  It should be
' imported into either a form or the Global section of the program.
'
' This file is ONLY for use with the 32 bit version of Visual BASIC.  If
' you are using the 16 bit version, then include GPIB-16.BAS instead.
'
' If you are using an existing National Instruments program, then
' you should replace the NIGLOBAL.BAS and VBIB.BAS files that are included
' in your poject with this file.
'
'***********************************************************************


'COMMON SHARED /GPIBVARS/ IBSTA%, IBERR%, IBCNT%, IBCNTL&
Global ibsta%, iberr%, ibcnt%, ibcntl&
Global GPIBInProgress%

' GPIB Commands
Global Const GTL = &H1
Global Const SDC = &H4
Global Const PPC = &H5
Global Const GETT = &H8
Global Const TCT = &H9
Global Const LLO = &H11
Global Const DCL = &H14
Global Const PPU = &H15
Global Const SPE = &H18
Global Const SPD = &H19
Global Const UNL = &H3F
Global Const UNT = &H5F
Global Const PPE = &H60
Global Const PPD = &H70


' Bit specifiers for ibsta status variable and wait mask
Global Const EERR = &H8000  ' Error detected
Global Const TIMO = &H4000  ' Timeout
Global Const EEND = &H2000  ' EOI or EOS detected
Global Const SRQI = &H1000  ' SRQ detected by CIC
Global Const RQS = &H800    ' Device needs service
Global Const SPOLL = &H400  ' Board has been serially polled
Global Const eevent = &H200 ' An event has occured
Global Const CMPL = &H100   ' I/O completed
Global Const LOK = &H80     ' Local lockout state
Global Const RREM = &H40    ' Remote state
Global Const CIC = &H20     ' Controller-in-Charge
Global Const AATN = &H10    ' Attention asserted
Global Const TACS = &H8     ' Talker active
Global Const LACS = &H4     ' Listener active
Global Const DTAS = &H2     ' Device trigger state
Global Const DCAS = &H1     ' Device clear state


' Error codes returned to IBERR variable
Global Const EDVR = 0     ' DOS error
Global Const ECIC = 1     ' Board must be CIC for this function
Global Const ENOL = 2     ' No listeners detected
Global Const EADR = 3     ' Board not addressed correctly
Global Const EARG = 4     ' Invalid argument passed to function
Global Const ESAC = 5     ' Function requires GPIB board to be SC
Global Const EABO = 6     ' I/O operation aborted
Global Const ENEB = 7     ' Invalid board specified
Global Const EOIP = 10    ' I/O operation already running
Global Const ECAP = 11    ' Board does not have requested capability
Global Const EFSO = 12    ' Error returned from file system
Global Const EBUS = 14    ' Command error on bus
Global Const ESTB = 15    ' Serial poll response byte lost
Global Const ESRQ = 16    ' SRQ is still asserted
Global Const ETAB = 20    ' No device responding with ETAB

Global Const EINT = 247   ' No interrupt configured on board.
Global Const EWMD = 248   ' Windows is not in enhanced mode
Global Const EVDD = 249   ' CBGPIB.386 is not installed
Global Const EOVR = 250   ' Buffer overflow
Global Const ESML = 251   ' Two library calls running simultaneously
Global Const ECFG = 252   ' Board type doesn't match GPIB.CFG
Global Const ETMR = 253   ' No Windows timers available
Global Const ESLC = 254   ' No Windows selectors available
Global Const EBRK = 255   ' Ctrl-Break pressed, exiting program


' EOS mode bits
Global Const BIN = &H1000
Global Const XEOS = &H800
Global Const REOS = &H400


' Timeout code for ibtmo function
Global Const TNONE = 0      ' No timeout
Global Const T10us = 1      ' 10 usec
Global Const T30us = 2      ' 30 usec
Global Const T100us = 3     ' 100 usec
Global Const T300us = 4     ' 300 usec
Global Const T1ms = 5       ' 1 msec
Global Const T3ms = 6       ' 3 msec
Global Const T10ms = 7      ' 10 msec
Global Const T30ms = 8      ' 30 msec
Global Const T100ms = 9     ' 100 msec
Global Const T300ms = 10    ' 300 msec
Global Const T1s = 11       ' 1 sec
Global Const T3s = 12       ' 3 sec
Global Const T10s = 13      ' 10 sec
Global Const T30s = 14      ' 30 sec
Global Const T100s = 15     ' 100 sec
Global Const T300s = 16     ' 300 sec
Global Const T1000s = 17    ' 1000 sec

'  IBLN Constants
Global Const NO_SAD = 0
Global Const ALL_SAD = -1


' Miscellaneous
Global Const S = &H8             ' parallel poll bit
Global Const LF = &HA            ' linefeed character
Global Const NOADDR = &HFFFF     'Terminator for address list
Global Const NULLend = 0         'Send() EOTMODE - Do nothing at the end of a transfer.
Global Const NLend = 1           'Send() EOTMODE - Send NL with EOI after a transfer.
Global Const DABend = 2          'Send() EOTMODE - Send EOI with the last DAB.
Global Const STOPend = &H100     'Receive()( termination
Global Const EventDTAS = 1       'used by IBEVENT()
Global Const EventDCAS = 2       'used by IBEVENT()


' The following constants are used with ibconfig() to select a
' configurable option.
Global Const IbcPAD = &H1             ' Primary address
Global Const IbcSAD = &H2             ' Secondary address
Global Const IbcTMO = &H3             ' Timeout
Global Const IbcEOT = &H4             ' Send EOI with last byte
Global Const IbcPPC = &H5             ' Parallel Poll Configure
Global Const IbcREADDR = &H6          ' Repeat Addressing
Global Const IbcAUTOPOLL = &H7        ' Disable automatic serial poll
Global Const IbcCICPROT = &H8         ' Use CIC Protocol
Global Const IbcIRQ = &H9             ' Interrupt level (or 0 for none)
Global Const IbcSC = &HA              ' Board is system controller
Global Const IbcSRE = &HB             ' Assert SRE for dev calls
Global Const IbcEOSrd = &HC           ' Terminate read on EOS
Global Const IbcEOSwrt = &HD          ' Send EOI with EOS
Global Const IbcEOScmp = &HE          ' Use 7 or 8-bit compare with EOS
Global Const IbcEOSchar = &HF         ' EOS character
Global Const IbcPP2 = &H10            ' Use PP mode 2
Global Const IbcTIMING = &H11         ' Normal, High or Very High Speed
Global Const IbcDMA = &H12            ' DMA channel (or 0 for none)
Global Const IbcReadAdjust = &H13     ' Swap bytes on read
Global Const IbcWriteAdjust = &H14    ' Swap bytes on write
Global Const IbcEventQueue = &H15     ' Use event queue
Global Const IbcSPollBit = &H16       ' Serial poll bit used
Global Const IbcSendLLO = &H17        ' Automatically send LLO
Global Const IbcSPollTime = &H18      ' Serial poll timeout
Global Const IbcPPollTime = &H19      ' Parallel poll timeout
Global Const IbcNoEndBitOnEos = &H1A  ' Don't set end bit on EOS
Global Const IbcBNA = &H200           ' A device's access board.
Global Const IbcBaseAddr = &H201      ' A GPIB board's base I/O address.

' CBP config items - Don't exist in NI software
Global Const IbcBoardType = &H300     ' Board type
Global Const IbcChipType = &H301      ' ChipType
Global Const IbcSlotNum = &H302       ' Slot Number
Global Const IbcPCIIndex = &H303      ' PCI Index
Global Const IbcBaseAdr2 = &H304      ' 2nd base address for PCI board
Global Const IbcUseFIFOs = &H305      ' When to use FIFOs


' These are provided for compatability with NI's library
Global Const IbaPAD = &H1
Global Const IbaSAD = &H2
Global Const IbaTMO = &H3
Global Const IbaEOT = &H4
Global Const IbaPPC = &H5
Global Const IbaREADDR = &H6
Global Const IbaAUTOPOLL = &H7
Global Const IbaCICPROT = &H8
Global Const IbaIRQ = &H9
Global Const IbaSC = &HA
Global Const IbaSRE = &HB
Global Const IbaEOSrd = &HC
Global Const IbaEOSwrt = &HD
Global Const IbaEOScmp = &HE
Global Const IbaEOSchar = &HF
Global Const IbaPP2 = &H10
Global Const IbaTIMING = &H11
Global Const IbaDMA = &H12
Global Const IbaReadAdjust = &H13
Global Const IbaWriteAdjust = &H14
Global Const IbaEventQueue = &H15
Global Const IbaSPollBit = &H16
Global Const IbaSendLLO = &H17
Global Const IbaSPollTime = &H18
Global Const IbaPPollTime = &H19
Global Const IbaNoEndBitOnEos = &H1A
Global Const IbaBNA = &H200
Global Const IbaBaseAddr = &H201

' CBI config items - Don't exist in NI software
Global Const IbaBoardType = &H300
Global Const IbaChipType = &H301
Global Const IbaSlotNum = &H302
Global Const IbaPCIIndex = &H303
Global Const IbaBaseAdr2 = &H304
Global Const IbaUseFIFOs = &H305


' These bits specify which lines can be monitored by IBLINES
Global Const ValidDAV = &H1
Global Const ValidNDAC = &H2
Global Const ValidNRFD = &H4
Global Const ValidIFC = &H8
Global Const ValidREN = &H10
Global Const ValidSRQ = &H20
Global Const ValidATN = &H40
Global Const ValidEOI = &H80

' These bits specify the current state of each GPIB line
Global Const BusDAV = &H100
Global Const BusNDAC = &H200
Global Const BusNRFD = &H400
Global Const BusIFC = &H800
Global Const BusREN = &H1000
Global Const BusSRQ = &H2000
Global Const BusATN = &H4000
Global Const BusEOI = &H8000



' GPIB-32.DLL routines
Declare Function ibask32 Lib "gpib-32.dll" (ByVal board%, ByVal Item%, value%) As Integer
Declare Function DLLibbna Lib "gpib-32.dll" (ByVal Device%, ByVal boardname$) As Integer
Declare Function DLLibcac Lib "gpib-32.dll" (ByVal Device%, ByVal sync%) As Integer
Declare Function DLLibclr Lib "gpib-32.dll" (ByVal Device%) As Integer
Declare Function DLLibcmd Lib "gpib-32.dll" (ByVal board%, ByVal cmnd$, ByVal cmdcount&) As Integer
Declare Function DLLibcmda Lib "gpib-32.dll" (ByVal board%, ByVal cmnd$, ByVal cmdcount&) As Integer
Declare Function DLLibconfig Lib "gpib-32.dll" (ByVal board%, ByVal Item%, ByVal value%) As Integer
Declare Function DLLibdev Lib "gpib-32.dll" (ByVal boardindex%, ByVal pad%, ByVal sad%, ByVal timeout%, ByVal eot%, ByVal eos%) As Integer
Declare Function DLLibdma Lib "gpib-32.dll" (ByVal board%, ByVal dma%) As Integer
Declare Function DLLibeos Lib "gpib-32.dll" (ByVal boarddev%, ByVal eos%) As Integer
Declare Function DLLibeot Lib "gpib-32.dll" (ByVal boarddev%, ByVal eot%) As Integer
Declare Function DLLibevent Lib "gpib-32.dll" (ByVal board%, eevent%) As Integer
Declare Function DLLibfind Lib "gpib-32.dll" (ByVal devname$) As Integer
Declare Function DLLibgts Lib "gpib-32.dll" (ByVal board%, ByVal handshake%) As Integer
Declare Function DLLibist Lib "gpib-32.dll" (ByVal board%, ByVal statusbit%) As Integer
Declare Function DLLibinit Lib "gpib-32.dll" (ByVal board%) As Integer
Declare Function DLLiblines Lib "gpib-32.dll" (ByVal board%, clines%) As Integer
Declare Function DLLibln Lib "gpib-32.dll" (ByVal board%, ByVal pad%, ByVal sad%, listenflag%) As Integer
Declare Function DLLibloc Lib "gpib-32.dll" (ByVal boarddev%) As Integer
Declare Function DLLibonl Lib "gpib-32.dll" (ByVal boarddev%, ByVal online%) As Integer
Declare Function DLLibpad Lib "gpib-32.dll" (ByVal boarddev%, ByVal address%) As Integer
Declare Function DLLibpct Lib "gpib-32.dll" (ByVal Device%) As Integer
Declare Function DLLibppc Lib "gpib-32.dll" (ByVal boarddev%, ByVal Cmd%) As Integer
Declare Function ibptrs Lib "gpib-32.dll" (ibstaPtr%, iberrPtr%, ibcntPtr%, ibcntlPtr&) As Integer
Declare Function DLLibrd Lib "gpib-32.dll" (ByVal boardev%, ByVal readstr$, ByVal rdcount&) As Integer
Declare Function DLLibrda Lib "gpib-32.dll" (ByVal boardev%, ByVal readstr$, ByVal rdcount&) As Integer
Declare Function DLLibrdf Lib "gpib-32.dll" (ByVal boardev%, ByVal filename$) As Integer
Declare Function DLLibrdi Lib "gpib-32.dll" (ByVal boarddev%, intarray%, ByVal count&) As Integer
Declare Function DLLibrdia Lib "gpib-32.dll" (ByVal boarddev%, intarray%, ByVal count&) As Integer
Declare Function DLLibrpp Lib "gpib-32.dll" (ByVal boarddev%, response%) As Integer
Declare Function DLLibrsc Lib "gpib-32.dll" (ByVal board%, ByVal ctrl%) As Integer
Declare Function DLLibrsp Lib "gpib-32.dll" (ByVal Device%, serialpollbyte%) As Integer
Declare Function DLLibrsv Lib "gpib-32.dll" (ByVal boarddev%, ByVal statusbyte%) As Integer
Declare Function DLLibsad Lib "gpib-32.dll" (ByVal boarddev%, ByVal address%) As Integer
Declare Function DLLibsic Lib "gpib-32.dll" (ByVal board%) As Integer
Declare Function DLLibsre Lib "gpib-32.dll" (ByVal board%, ByVal ren%) As Integer
Declare Function DLLibstop Lib "gpib-32.dll" (ByVal boarddev%) As Integer
Declare Function DLLibtmo Lib "gpib-32.dll" (ByVal boarddev%, ByVal timeout%) As Integer
Declare Function DLLibtrg Lib "gpib-32.dll" (ByVal Device%) As Integer
Declare Function DLLibwait Lib "gpib-32.dll" (ByVal boarddev%, ByVal mask%) As Integer
Declare Function DLLibwrt Lib "gpib-32.dll" (ByVal boarddev%, ByVal writestr$, ByVal strcount&) As Integer
Declare Function DLLibwrta Lib "gpib-32.dll" (ByVal boarddev%, ByVal writestr$, ByVal strcount&) As Integer
Declare Function DLLibwrtf Lib "gpib-32.dll" (ByVal boarddev%, ByVal filename$) As Integer
Declare Function DLLibwrti Lib "gpib-32.dll" (ByVal boarddev%, intarray%, ByVal count&) As Integer
Declare Function DLLibwrtia Lib "gpib-32.dll" (ByVal boarddev%, intarray%, ByVal count&) As Integer

Declare Sub DLLAllSpoll Lib "gpib-32.dll" (ByVal dev%, adrlist%, results%)
Declare Sub DLLDevClear Lib "gpib-32.dll" (ByVal dev%, ByVal adr%)
Declare Sub DLLDevClearList Lib "gpib-32.dll" (ByValdev%, adrlist%)
Declare Sub DLLEnableLocal Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLEnableRemote Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLFindLstn Lib "gpib-32.dll" (ByVal dev%, adrlist%, results%, ByVal limit%)
Declare Sub DLLFindRQS Lib "gpib-32.dll" (ByVal dev%, adrlist%, result%)
Declare Sub DLLPassControl Lib "gpib-32.dll" (ByVal dev%, ByVal adr%)
Declare Sub DLLPPoll Lib "gpib-32.dll" (ByVal dev%, result%)
Declare Sub DLLPPollConfig Lib "gpib-32.dll" (ByVal dev%, ByVal adr%, ByVal lline%, ByVal sense%)
Declare Sub DLLPPollUnconfig Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLReadStatusByte Lib "gpib-32.dll" (ByVal dev%, ByVal adr%, result%)
Declare Sub DLLRcvRespMsg Lib "gpib-32.dll" (ByVal adr%, ByVal buf$, ByVal length&, ByVal term%)
Declare Sub DLLReceive Lib "gpib-32.dll" (ByVal dev%, ByVal adr%, ByVal buf$, ByVal count&, ByVal term%)
Declare Sub DLLReceiveSetup Lib "gpib-32.dll" (ByVal dev%, ByVal adr%)
Declare Sub DLLResetSys Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLSend Lib "gpib-32.dll" (ByVal dev%, ByVal adr%, ByVal buf$, ByVal length&, ByVal term%)
Declare Sub DLLSendDataBytes Lib "gpib-32.dll" (ByVal board%, ByVal buf$, ByVal length&, ByVal term%)
Declare Sub DLLSendCmds Lib "gpib-32.dll" (ByVal dev%, ByVal cmdbuf$, ByVal length&)
Declare Sub DLLSendIFC Lib "gpib-32.dll" (ByVal dev%)
Declare Sub DLLSendList Lib "gpib-32.dll" (ByVal dev%, adr%, ByVal buf$, ByVal length&, ByVal term%)
Declare Sub DLLSendLLO Lib "gpib-32.dll" (ByVal dev%)
Declare Sub DLLSendSetup Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLSetRWLS Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLTestSRQ Lib "gpib-32.dll" (ByVal dev%, result%)
Declare Sub DLLTestSys Lib "gpib-32.dll" (ByVal dev%, adrlist%, results%)
Declare Sub DLLTrigger Lib "gpib-32.dll" (ByVal dev%, ByVal adr%)
Declare Sub DLLTriggerList Lib "gpib-32.dll" (ByVal dev%, adrlist%)
Declare Sub DLLWaitSRQ Lib "gpib-32.dll" (ByVal dev%, result%)
Declare Sub DLLGetIBVars Lib "gpib-32.dll" (ibsta%, iberr%, ibcnt%, ibcntl&)


'************************
' 488.1 Functions
'************************

Function ilask(dev%, opt%, rval%) As Integer
    ilask% = ibask32(dev%, opt%, rval%)
    ibcnt% = ibcntl&
End Function

Function ilbna(dev%, devname$) As Integer
    ilbna% = DLLibbna(dev%, ByVal devname$)
    Call copy_globals
End Function

Function ilcac(dev%, v%) As Integer
    ilcac% = DLLibcac(dev%, v%)
    Call copy_globals
End Function

Function ilclr(dev%) As Integer
    ilclr% = DLLibclr(dev%)
    Call copy_globals
End Function

Function ilcmd(dev%, buf$, cnt&) As Integer
    ilcmd% = DLLibcmd(dev%, ByVal buf$, cnt&)
    Call copy_globals
End Function

Function ilcmda(dev%, buf$, cnt&) As Integer
    ilcmda% = DLLibcmda(dev%, ByVal buf$, cnt&)
    Call copy_globals
End Function

Function ilconfig(bdid%, opt%, v%) As Integer
    ilconfig% = DLLibconfig(bdid%, opt%, v%)
    Call copy_globals
End Function

Function ildev(bdid%, pad%, sad%, tmo%, eot%, eos%) As Integer
    ildev% = DLLibdev(bdid%, pad%, sad%, tmo%, eot%, eos%)
    Call copy_globals
End Function

Function ildma(dev%, v%) As Integer
    ildma% = DLLibdma(dev%, v%)
    Call copy_globals
End Function

Function ileos(dev%, v%) As Integer
    ileos% = DLLibeos(dev%, v%)
    Call copy_globals
End Function

Function ileot(dev%, v%) As Integer
    ileot% = DLLibeot(dev%, v%)
    Call copy_globals
End Function

Function ilevent(dev%, eevent%) As Integer
    ilevent% = DLLibevent(dev%, eevent%)
    Call copy_globals
End Function

Function ilfind(devname$) As Integer
    ilfind% = DLLibfind(devname$)
    Call copy_globals
End Function

Function ilgts(dev%, v%) As Integer
    ilgts% = DLLibgts(dev%, v%)
    Call copy_globals
End Function

Function ilinit(dev%) As Integer
    ilinit% = DLLibinit(dev%)
    Call copy_globals
End Function

Function ilist(dev%, v%) As Integer
    ilist% = DLLibist(dev%, v%)
    Call copy_globals
End Function

Function illines(dev%, lines%) As Integer
    illines% = DLLiblines(dev%, lines%)
    Call copy_globals
End Function

Function illn(dev%, pad%, sad%, listener%) As Integer
    illn% = DLLibln(dev%, pad%, sad%, listener%)
    Call copy_globals
End Function

Function illoc(dev%) As Integer
    illoc% = DLLibloc(dev%)
    Call copy_globals
End Function

Function ilonl(dev%, v%) As Integer
    ilonl% = DLLibonl(dev%, v%)
    Call copy_globals
End Function

Function ilpad(dev%, v%) As Integer
    ilpad% = DLLibpad(dev%, v%)
    Call copy_globals
End Function

Function ilpct(dev%) As Integer
    ilpct% = DLLibpct(dev%)
    Call copy_globals
End Function

Function ilppc(dev%, v%) As Integer
    ilppc% = DLLibppc(dev%, v%)
    Call copy_globals
End Function

Function ilrd(dev%, buf$, cnt&) As Integer
    ilrd% = DLLibrd(dev%, ByVal buf$, cnt&)
    Call copy_globals
End Function

Function ilrda(dev%, buf$, cnt&) As Integer
    ilrda% = DLLibrda(dev%, ByVal buf$, cnt&)
    Call copy_globals
End Function

Function ilrdf(dev%, filename$) As Integer
    ilrdf% = DLLibrdf(dev%, ByVal filename$)
    Call copy_globals
End Function

Function ilrdi(dev%, ibuf%(), cnt&) As Integer
    ilrdi% = DLLibrdi(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Function

Function ilrdia(dev%, ibuf%(), cnt&) As Integer
    ilrdia% = DLLibrdia(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Function

Function ilrpp(dev%, ppr%) As Integer
    ilrpp% = DLLibrpp(dev%, ppr%)
    Call copy_globals
End Function

Function ilrsc(dev%, v%) As Integer
    ilrsc% = DLLibrsc(dev%, v%)
    Call copy_globals
End Function

Function ilrsp(dev%, rsp%) As Integer
    ilrsp% = DLLibrsp(dev%, rsp%)
    Call copy_globals
End Function

Function ilrsv(dev%, v%) As Integer
    ilrsv% = DLLibrsv(dev%, v%)
    Call copy_globals
End Function

Function ilsad(dev%, v%) As Integer
    ilsad% = DLLibsad(dev%, v%)
    Call copy_globals
End Function

Function ilsic(dev%) As Integer
    ilsic% = DLLibsic(dev%)
    Call copy_globals
End Function

Function ilsre(dev%, v%) As Integer
    ilsre% = DLLibsre(dev%, v%)
    Call copy_globals
End Function

Function ilstop(dev%) As Integer
    ilstop% = DLLibstop(dev%)
    Call copy_globals
End Function

Function ILTMO(dev%, v%) As Integer
    ILTMO% = DLLibtmo(dev%, v%)
    Call copy_globals
End Function

Function iltrg(dev%) As Integer
    iltrg% = DLLibtrg(dev%)
    Call copy_globals
End Function

Function ilwait(dev%, mask%) As Integer
    ilwait% = DLLibwait(dev%, mask)
    Call copy_globals
End Function

Function ilwrt(dev%, buf$, cnt&) As Integer
    ilwrt% = DLLibwrt(dev%, ByVal buf$, cnt&)
    Call copy_globals
End Function

Function ilwrta(dev%, buf$, cnt&) As Integer
    ilwrta% = DLLibwrta(dev%, ByVal buf$, cnt&)
    Call copy_globals
End Function

Function ilwrtf(dev%, filename$) As Integer
    ilwrtf% = DLLibwrtf(dev%, ByVal filename$)
    Call copy_globals
End Function

Function ilwrti(dev%, ibuf%(), cnt&) As Integer
    ilwrti% = DLLibwrti(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Function

Function ilwrtia(dev%, ibuf%(), cnt&) As Integer
    ilwrtia% = DLLibwrtia(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Function


'************************
' 488.1 Subroutines
'************************

Sub ibask(dev%, opt%, rval%)
    a% = ibask32(dev%, opt%, rval%)
    ibcnt% = ibcntl&
End Sub

Sub ibbna(dev%, devname$)
    a% = DLLibbna(dev%, ByVal devname$)
    Call copy_globals
End Sub

Sub ibcac(dev%, v%)
    a% = DLLibcac(dev%, v%)
    Call copy_globals
End Sub

Sub ibclr(dev%)
    a% = DLLibclr(dev%)
    Call copy_globals
End Sub

Sub ibcmd(dev%, buf$)
    a% = DLLibcmd(dev%, ByVal buf$, Len(buf$))
    Call copy_globals
End Sub

Sub ibcmda(dev%, buf$)
    aa% = DLLibcmda(dev%, ByVal buf$, Len(buf$))
    Call copy_globals
End Sub

Sub ibconfig(bdid%, opt%, v%)
    afig% = DLLibconfig(bdid%, opt%, v%)
    Call copy_globals
End Sub

Sub ibdev(bdid%, pad%, sad%, tmo%, eot%, eos%, dev%)
    dev% = DLLibdev(bdid%, pad%, sad%, tmo%, eot%, eos%)
    Call copy_globals
End Sub

Sub ibdma(dev%, v%)
    a% = DLLibdma(dev%, v%)
    Call copy_globals
End Sub

Sub ibeos(dev%, v%)
    a% = DLLibeos(dev%, v%)
    Call copy_globals
End Sub

Sub ibeot(dev%, v%)
    a% = DLLibeot(dev%, v%)
    Call copy_globals
End Sub

Sub ibevent(dev%, eevent%)
    ant% = DLLibevent(dev%, eevent%)
    Call copy_globals
End Sub

Sub ibfind(devname$, dev%)
    dev% = DLLibfind(devname$)
    Call copy_globals
End Sub

Sub ibgts(dev%, v%)
    a% = DLLibgts(dev%, v%)
    Call copy_globals
End Sub

Sub ibinit(dev%)
    a% = DLLibinit(dev%)
    Call copy_globals
End Sub

Sub ibist(dev%, v%)
    a% = DLLibist(dev%, v%)
    Call copy_globals
End Sub

Sub iblines(dev%, lines%)
    aes% = DLLiblines(dev%, lines%)
    Call copy_globals
End Sub

Sub ibln(dev%, pad%, sad%, listener%)
    a = DLLibln(dev%, pad%, sad%, listener%)
    Call copy_globals
End Sub

Sub ibloc(dev%)
    a% = DLLibloc(dev%)
    Call copy_globals
End Sub

Sub ibonl(dev%, v%)
    a% = DLLibonl(dev%, v%)
    Call copy_globals
End Sub

Sub ibpad(dev%, v%)
    a% = DLLibpad(dev%, v%)
    Call copy_globals
End Sub

Sub ibpct(dev%)
    a% = DLLibpct(dev%)
    Call copy_globals
End Sub

Sub ibppc(dev%, v%)
    a% = DLLibppc(dev%, v%)
    Call copy_globals
End Sub

Sub ibrd(dev%, buf$)
    a% = DLLibrd(dev%, ByVal buf$, Len(buf$))
    Call copy_globals
End Sub

Sub ibrda(dev%, buf$)
    a% = DLLibrda(dev%, ByVal buf$, Len(buf$))
    Call copy_globals
End Sub

Sub ibrdf(dev%, filename$)
    a% = DLLibrdf(dev%, ByVal filename$)
    Call copy_globals
End Sub

Sub ibrdi(dev%, ibuf%(), cnt&)
    a% = DLLibrdi(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Sub

Sub ibrdia(dev%, ibuf%(), cnt&)
    aa% = DLLibrdia(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Sub

Sub ibrpp(dev%, ppr%)
    a% = DLLibrpp(dev%, ppr%)
    Call copy_globals
End Sub

Sub ibrsc(dev%, v%)
    a% = DLLibrsc(dev%, v%)
    Call copy_globals
End Sub

Sub ibrsp(dev%, rsp%)
    a% = DLLibrsp(dev%, rsp%)
    Call copy_globals
End Sub

Sub ibrsv(dev%, v%)
    a% = DLLibrsv(dev%, v%)
    Call copy_globals
End Sub

Sub ibsad(dev%, v%)
    a% = DLLibsad(dev%, v%)
    Call copy_globals
End Sub

Sub ibsic(dev%)
    a% = DLLibsic(dev%)
    Call copy_globals
End Sub

Sub ibsre(dev%, v%)
    a% = DLLibsre(dev%, v%)
    Call copy_globals
End Sub

Sub ibstop(dev%)
    ap% = DLLibstop(dev%)
    Call copy_globals
End Sub

Sub ibtmo(dev%, v%)
    a% = DLLibtmo(dev%, v%)
    Call copy_globals
End Sub

Sub ibtrg(dev%)
    a% = DLLibtrg(dev%)
    Call copy_globals
End Sub

Sub ibwait(dev%, mask%)
    at% = DLLibwait(dev%, mask)
    Call copy_globals
End Sub

Sub ibwrt(dev%, buf$)
    a% = DLLibwrt(dev%, ByVal buf$, Len(buf$))
    Call copy_globals
End Sub

Sub ibwrta(dev%, buf$)
    aa% = DLLibwrta(dev%, ByVal buf$, Len(buf$))
    Call copy_globals
End Sub

Sub ibwrtf(dev%, filename$)
    af% = DLLibwrtf(dev%, ByVal filename$)
    Call copy_globals
End Sub

Sub ibwrti(dev%, ibuf%(), cnt&)
    ai% = DLLibwrti(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Sub

Sub ibwrtia(dev%, ibuf%(), cnt&)
    aia% = DLLibwrtia(dev%, ibuf%(0), cnt&)
    Call copy_globals
End Sub



'************************
' 488.2 Subroutines
'************************
Sub copy_globals()
    Call DLLGetIBVars(ibsta%, iberr%, ibcnt%, ibcntl&)
End Sub

Sub AllSpoll(ByVal dev%, adrlist%(), results%())
    Call DLLAllSpoll(ByVal dev%, adrlist%(0), results%(0))
    Call copy_globals
End Sub

Sub DevClear(ByVal dev%, ByVal adr%)
    Call DLLDevClear(ByVal dev%, ByVal adr%)
    Call copy_globals
End Sub

Sub DevClearList(ByValdev%, adrlist%())
    Call DLLDevClearList(ByValdev%, adrlist%(0))
    Call copy_globals
End Sub

Sub EnableLocal(ByVal dev%, adrlist%())
    Call DLLEnableLocal(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub EnableRemote(ByVal dev%, adrlist%())
    Call DLLEnableRemote(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub FindLstn(ByVal dev%, adrlist%(), results%(), ByVal limit%)
    Call DLLFindLstn(ByVal dev%, adrlist%(0), results%(0), ByVal limit%)
    Call copy_globals
End Sub

Sub FindRQS(ByVal dev%, adrlist%(), result%)
    Call DLLFindRQS(ByVal dev%, adrlist%(0), result%)
    Call copy_globals
End Sub

Sub PassControl(ByVal dev%, ByVal adr%)
    Call DLLPassControl(ByVal dev%, ByVal adr%)
    Call copy_globals
End Sub

Sub PPoll(ByVal dev%, result%)
    Call DLLPPoll(ByVal dev%, result%)
    Call copy_globals
End Sub

Sub PPollConfig(ByVal dev%, ByVal adr%, ByVal lline%, ByVal sense%)
    Call DLLPPollConfig(ByVal dev%, ByVal adr%, ByVal lline%, ByVal sense%)
    Call copy_globals
End Sub

Sub PPollUnconfig(ByVal dev%, adrlist%())
    Call DLLPPollUnconfig(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub RcvRespMsg(board%, buf$, term%)
    length& = Len(buf$)
    Call DLLRcvRespMsg(ByVal board%, ByVal buf$, ByVal length&, ByVal trem%)
    Call copy_globals
End Sub

Sub ReadStatusByte(ByVal dev%, ByVal adr%, result%)
    Call DLLReadStatusByte(ByVal dev%, ByVal adr%, result%)
    Call copy_globals
End Sub

Sub Receive(dev%, adr%, buf$, term%)
    length& = Len(buf$)
    Call DLLReceive(dev%, ByVal adr%, ByVal buf$, ByVal length&, ByVal term%)
    Call copy_globals
End Sub

Sub ReceiveSetup(ByVal dev%, ByVal adr%)
    Call DLLReceiveSetup(ByVal dev%, ByVal adr%)
    Call copy_globals
End Sub

Sub ResetSys(ByVal dev%, adrlist%())
    Call DLLResetSys(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub Send(dev%, adr%, buf$, term%)
    length& = Len(buf$)
    Call DLLSend(dev%, adr%, ByVal buf$, ByVal length&, ByVal term%)
    Call copy_globals
End Sub

Sub SendCmds(dev%, cmdbuf$)
    length& = Len(cmdbuf$)
    Call DLLSendCmds(dev%, ByVal cmdbuf$, ByVal length&)
    Call copy_globals
End Sub

Sub SendDataBytes(board%, buf$, term%)
    length& = Len(buf$)
    Call DLLSendDataBytes(board%, ByVal buf$, ByVal length&, ByVal term%)
    Call copy_globals
End Sub

Sub SendIFC(ByVal dev%)
    Call DLLSendIFC(ByVal dev%)
    Call copy_globals
End Sub

Sub SendList(dev%, adr%(), buf$, term%)
    length& = Len(buf$)
    Call DLLSendList(dev%, adr%(0), ByVal buf$, ByVal length&, ByVal term%)
    Call copy_globals
End Sub

Sub SendLLO(ByVal dev%)
    Call DLLSendLLO(ByVal dev%)
    Call copy_globals
End Sub

Sub SendSetup(ByVal dev%, adrlist%())
    Call DLLSendSetup(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub SetRWLS(ByVal dev%, adrlist%())
    Call DLLSetRWLS(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub TestSRQ(ByVal dev%, result%)
    Call DLLTestSRQ(ByVal dev%, result%)
    Call copy_globals
End Sub

Sub TestSys(ByVal dev%, adrlist%(), results%())
    Call DLLTestSys(ByVal dev%, adrlist%(0), results%(0))
    Call copy_globals
End Sub

Sub Trigger(ByVal dev%, ByVal adr%)
    Call DLLTrigger(ByVal dev%, ByVal adr%)
    Call copy_globals
End Sub

Sub TriggerList(ByVal dev%, adrlist%())
    Call DLLTriggerList(ByVal dev%, adrlist%(0))
    Call copy_globals
End Sub

Sub WaitSRQ(ByVal dev%, result%)
    Call DLLWaitSRQ(ByVal dev%, result%)
    Call copy_globals
End Sub


Public Sub gpiberr(Msg$)
'=============================================================================
'                      Subroutine GPIBERR
'  This subroutine will notify you that a NI-488.2 subroutine failed by
'  printing an error message.  The status variable IBSTA% will also be
'  printed in hexadecimal along with the mnemonic meaning of the bit position.
'  The status variable IBERR% will be printed in decimal along with the
'  mnemonic meaning of the decimal value.  The status variable IBCNTL& will
'  be printed in decimal.
'
'  The NI-488 function IBONL is called to disable the hardware and software.
'=============================================================================
'


  
  Msg$ = Msg$ + NL + " ibsta = &H" + Hex$(ibsta%) + " <" + NL

   If ibsta% And EERR Then EMsg$ = " ERR"
   If ibsta% And TIMO Then EMsg$ = " TIMO"
   If ibsta% And EEND Then EMsg$ = " END"
   If ibsta% And SRQI Then EMsg$ = " SRQI"
   If ibsta% And RQS Then EMsg$ = " RQS"
   If ibsta% And SPOLL Then EMsg$ = " SPOLL"
   If ibsta% And eevent Then EMsg$ = " EVENT"
   If ibsta% And CMPL Then EMsg$ = " CMPL"
   If ibsta% And LOK Then EMsg$ = " LOK"
   If ibsta% And RREM Then EMsg$ = " REM"
   If ibsta% And CIC Then EMsg$ = " CIC"
   If ibsta% And AATN Then EMsg$ = " ATN"
   If ibsta% And TACS Then EMsg$ = " TACS"
   If ibsta% And LACS Then EMsg$ = " LACS"
   If ibsta% And DTAS Then EMsg$ = " DTAS"
   If ibsta% And DCAS Then EMsg$ = " DCAS"
   Msg = Msg + "  " + EMsg$ + " >" + "iberr = " + Str$(iberr%) + NL
  
   If iberr% = EDVR Then EMsg$ = " EDVR <DOS Error>"
   If iberr% = ECIC Then EMsg$ = " ECIC <Not CIC>"
   If iberr% = ENOL Then EMsg$ = " ENOL <No Listener>"
   If iberr% = EADR Then EMsg$ = " EADR <Address error>"
   If iberr% = EARG Then EMsg$ = " EARG <Invalid argument>"
   If iberr% = ESAC Then EMsg$ = " ESAC <Not Sys Ctrlr>"
   If iberr% = EABO Then EMsg$ = " EABO <Op. aborted>"
   If iberr% = ENEB Then EMsg$ = " ENEB <No GPIB board>"
   If iberr% = EOIP Then EMsg$ = " EOIP <Async I/O in prg>"
   If iberr% = ECAP Then EMsg$ = " ECAP <No capability>"
   If iberr% = EFSO Then EMsg$ = " EFSO <File sys. error>"
   If iberr% = EBUS Then EMsg$ = " EBUS <Command error>"
   If iberr% = ESTB Then EMsg$ = " ESTB <Status byte lost>"
   If iberr% = ESRQ Then EMsg$ = " ESRQ <SRQ stuck on>"
   If iberr% = ETAB Then EMsg$ = " ETAB <Table Overflow>"
  
   Msg$ = Msg$ + EMsg$ + "ibcnt = " + Str$(ibcntl&)
   RetMsg$ = Msg$
'  Call the IBONL function to disable the hardware and software.
  
   Call ibonl(0, 0)
   
End Sub
Public Sub SendCmd(BD%, dev%, Cmd$, EndPar)    'sends serial or GPIB command
      Call Send(BD%, dev%, Cmd$, NLend)
End Sub
Public Sub TalkToHP3631(B$, Unit)
'Dim ADDRLIST%(10)
'ADDRLIST%(1) = Unit
'ADDRLIST%(2) = NOADDR
    'Call Send(0, Unit, B$, DABend)
    Call SendCmd(BD%, 11, B$, EOTMode)


End Sub
'Public Sub pause(PauseTime)
'Dim start, roll_over
'start = Timer   ' Set start time.
'roll_over = Timer   ' Set start time.
'    Do While (Timer < start + PauseTime) And (roll_over >= start)
'        DoEvents    ' Yield to other processes.
'        roll_over = Timer
'    Loop
    

'End Sub



